@@ -20,12 +20,30 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include <gkrellm/gkrellm.h>
+#if 0
+/* Many deprecated functions are still used. */
+#define GDK_DISABLE_DEPRECATED
+#define GTK_DISABLE_DEPRECATED
+#endif
+
+
+#if !defined(WIN32)
+#include <gkrellm2/gkrellm.h>
+#else
+#include <src/gkrellm.h>
+#include <src/win32-plugin.h>
+#define F_RDLCK 0
+#define S_IRUSR 0
+#define S_IWUSR 0
+#define S_IXUSR 0
+#define F_WRLCK 0
+#endif
+
 #include <errno.h>
 
 static gchar *str_title = "gkrellm-reminder";
-static gchar *str_version = "0.3.5";
-static gchar *str_date = "2/11/2002";
+static gchar *str_version = "2.0.0";
+static gchar *str_date = "12/3/2002";
 static gchar *str_copyright = "Copyright (c) 2001, 2002";
 static gchar *str_author = "James Simonsen";
 static gchar *str_email = "simonjam@ucs.orst.edu";
@@ -113,16 +131,15 @@ static struct event_stored *head_stored;
 static struct event_stored *head_temp;
 static struct id_list *head_delete;
 
-static Monitor *reminder_mon;
+static GkrellmMonitor *reminder_mon;
 
-static Panel *panel;
-static Decal *reminder_icon_decal;
-static Decal *reminder_text_decal;
-static DecalButton *reminder_text_button;
-static GdkImlibImage *reminder_icon_image;
-static GdkPixmap *reminder_icon_pixmap;
-static GdkBitmap *reminder_icon_mask;
+static GkrellmPanel *panel;
+static GkrellmDecal *reminder_icon_decal;
+static GkrellmDecal *reminder_text_decal;
+static GkrellmDecalbutton *reminder_text_button;
+static GkrellmPiximage *reminder_icon_image;
 static gint style_id;
+static GkrellmTicks	*pGK;
 
 static gint num_active, num_today;
 static glong today_day;
@@ -197,7 +214,7 @@ static GtkWidget *entry_notify;
 static GtkWidget *window_today;
 
 static const gchar *str_delayed = "(Delayed) ";
-static const gchar *str_null = "";
+static const gchar *str_null;
 static const gchar *str_12hour = "%I:%M %p";
 static const gchar *str_24hour = "%H:%M";
 static const gchar *str_mdy = "%a %b %d %Y";
@@ -209,6 +226,7 @@ static void reminder_display_reminder( void );
 static int
 reminder_lock_db( FILE *fp, int type )
 {
+#if !defined(WIN32)
   struct flock lock;
 
   lock.l_type = type;
@@ -217,11 +235,15 @@ reminder_lock_db( FILE *fp, int type )
   lock.l_len = 0;
 
   return fcntl( fileno( fp ), F_SETLKW, &lock );
+#else
+    return 0;
+#endif
 }
 
 static int
 reminder_unlock_db( FILE *fp )
 {
+#if !defined(WIN32)
   struct flock lock;
 
   lock.l_type = F_UNLCK;
@@ -230,6 +252,9 @@ reminder_unlock_db( FILE *fp )
   lock.l_len = 0;
 
   return fcntl( fileno( fp ), F_SETLK, &lock );
+#else
+  return 0;
+#endif
 }
 
 static void
@@ -262,7 +287,7 @@ reminder_free_stored( struct event_stored **head_list )
     {
       next = current->next;
 
-      free( current->name );
+      g_free( current->name );
       free( current );
 
       current = next;
@@ -288,7 +313,8 @@ reminder_load_stored()
 
   if( reminder_lock_db( fp, F_RDLCK ) )
     {
-      gkrellm_message_window( str_title, "ERROR: Unable to lock event database for reading.", NULL );
+      gkrellm_message_window( str_title,
+          "ERROR: Unable to lock event database for reading.", NULL );
       return;
     }
 
@@ -298,18 +324,20 @@ reminder_load_stored()
       if( !current )
 	break;
 
-      current->name = malloc( strlen( buffer ) + 1 );
-      if( !current->name )
-	{
-	  free( current );
-	  break;
-	}
-      strcpy( current->name, buffer );
+//      current->name = malloc( strlen( buffer ) + 1 );
+//      if( !current->name )
+//	{
+//	  free( current );
+//	  break;
+//	}
+  //    strcpy( current->name, buffer );
+      current->name = g_strdup(buffer);
 
-      if( fscanf( fp, "%u %d %d %ld %ld %ld\n", &current->id, &current->days, &current->occurs,
-		  &current->start, &current->end, &current->last_displayed ) != 6 )
+      if( fscanf( fp, "%u %d %d %ld %ld %ld\n", &current->id, &current->days,
+          &current->occurs, &current->start, &current->end,
+          &current->last_displayed ) != 6 )
 	{
-	  free( current->name );
+	  g_free( current->name );
 	  free( current );
 	  break;
 	}
@@ -345,7 +373,7 @@ reminder_save_stored()
     {
       if( errno == ENOENT )
 	{
-	  char *dir;
+      char *dir;
 	  char *slash;
 
 	  dir = malloc( strlen( config.event_file ) );
@@ -362,7 +390,11 @@ reminder_save_stored()
 	    }
 	  *slash = '\0';
 
+#if !defined(WIN32)
 	  mkdir( dir, S_IRUSR | S_IWUSR | S_IXUSR );
+#else
+      mkdir(dir);
+#endif
 
 	  fp = fopen( config.event_file, "w" );
 	  if( !fp )
@@ -384,11 +416,17 @@ reminder_save_stored()
       return;
     }
 
+#if defined(WIN32)
+  // win32 can't lock the file, so just overwrite it
+  fclose(fp);
+  fopen( config.event_file, "w" );
+#else
   if( ftruncate( fileno( fp ), 0 ) )
     {
       gkrellm_message_window( str_title, "ERROR: Unable to truncate event database.", NULL );
       return;
     }
+#endif
 
   current = head_stored;
   while( current )
@@ -415,7 +453,7 @@ reminder_remove_event_today( guint id )
     {
       temp = head_today->next;
 
-      free( head_today->name );
+      g_free( head_today->name );
       free( head_today );
 
       head_today = temp;
@@ -430,7 +468,7 @@ reminder_remove_event_today( guint id )
 	    {
 	      temp = current->next->next;
 
-	      free( current->next->name );
+	      g_free( current->next->name );
 	      free( current->next );
 
 	      current->next = temp;
@@ -458,7 +496,7 @@ reminder_remove_event_stored( struct event_stored **head_list, guint id )
     {
       temp = (*head_list)->next;
 
-      free( (*head_list)->name );
+      g_free( (*head_list)->name );
       free( *head_list );
 
       *head_list = temp;
@@ -475,7 +513,7 @@ reminder_remove_event_stored( struct event_stored **head_list, guint id )
 	    {
 	      temp = current->next->next;
 
-	      free( current->next->name );
+	      g_free( current->next->name );
 	      free( current->next );
 
 	      current->next = temp;
@@ -519,7 +557,7 @@ reminder_free_today()
     {
       next = current->next;
 
-      free( current->name );
+      g_free( current->name );
       free( current );
 
       current = next;
@@ -672,11 +710,12 @@ reminder_create_event_today( struct event_stored *stored, struct tm *tm_stored,
   if( !new )
     return NULL;
 
-  new->name = malloc( strlen( stored->name ) + 1 );
-  if( !new->name )
-    return NULL;
+//  new->name = malloc( strlen( stored->name ) + 1 );
+//  if( !new->name )
+//    return NULL;
 
-  strcpy( new->name, stored->name );
+  //strcpy( new->name, stored->name );
+  new->name = g_strdup(stored->name);
 
   memcpy( &tm_new, gkrellm_get_current_time(), sizeof( tm_new ) );
 
@@ -749,7 +788,7 @@ reminder_weed_today( time_t now )
     {
       next = weed->next;
 
-      free( weed->name );
+      g_free( weed->name );
       free( weed );
 
       weed = next;
@@ -766,16 +805,18 @@ reminder_notify()
   if( !config.notify )
     return;
 
-  cmd = malloc( strlen( config.notify ) + 2 + 1 );
-  if( !cmd )
-    return;
+//  cmd = malloc( strlen( config.notify ) + 2 + 1 );
+//  if( !cmd )
+//    return;
 
-  strcpy( cmd, config.notify );
-  strcpy( cmd + strlen( cmd ), " &" );
+//  strcpy( cmd, config.notify );
+//  strcpy( cmd + strlen( cmd ), " &" );
+  cmd = g_strdup_printf("%s &", config.notify);
 
-  gkrellm_system( cmd );
+//  gkrellm_system( cmd );
+  g_spawn_command_line_async(cmd, NULL);
 
-  free( cmd );
+  g_free( cmd );
 }
 
 static void
@@ -999,19 +1040,21 @@ cb_select_radio( GtkWidget *window, gpointer data )
 static gchar *
 reminder_get_days_string( struct event_stored *current )
 {
-  int pos = 0;
-  gchar *string;
+  gchar *string = NULL;
+  gchar *string2;
 
-  string = malloc( 37 );
-  if( !string )
-    return NULL;
+//  string = malloc( 37 );
+//  if( !string )
+//    return NULL;
 
   if( current->occurs == OPT_DAILY )
     {
       if( current->days == 1 )
-	sprintf( string, "Everyday" );
+	//sprintf( string, "Everyday" );
+    string = g_strdup_printf("Everyday");
       else
-	sprintf( string, "Every %d days", current->days );
+	//sprintf( string, "Every %d days", current->days );
+      string = g_strdup_printf("Every %d days", current->days);
     }
   else if( current->occurs == OPT_WEEKLY )
     {
@@ -1020,19 +1063,23 @@ reminder_get_days_string( struct event_stored *current )
 
       if( days == 127 )
 	{
-	  pos = sprintf( string, "Everyday" );
+	  //pos = sprintf( string, "Everyday" );
+          string = g_strdup_printf("Everyday");
 	}
       else if( days == 62 )
 	{
-	  pos = sprintf( string, "Every weekday" );
+	  //pos = sprintf( string, "Every weekday" );
+          string = g_strdup_printf("Every weekday");
 	}
       else if( days == 65 )
 	{
-	  pos = sprintf( string, "Every weekend" );
+	  //pos = sprintf( string, "Every weekend" );
+          string = g_strdup_printf("Every weekend");
 	}
       else
 	{
-	  pos = sprintf( string, "%s%s%s%s%s%s%s",
+	  //pos = sprintf( string, "%s%s%s%s%s%s%s",
+          string = g_strdup_printf("%s%s%s%s%s%s%s",
 			 current->days & 1 ? "Sun " : str_null,
 			 current->days & 2 ? "Mon " : str_null,
 			 current->days & 4 ? "Tue " : str_null,
@@ -1043,7 +1090,12 @@ reminder_get_days_string( struct event_stored *current )
 	}
 
       if( weeks > 1 )
-	sprintf( string + pos, "; Every %d weeks", weeks );
+	//sprintf( string + pos, "; Every %d weeks", weeks );
+		{
+        string2 = g_strdup_printf("; Every %d weeks", weeks );
+        g_strconcat(string, string2, NULL);
+        g_free(string2);
+		}
     }
   else if( current->occurs == OPT_MONTHLY )
     {
@@ -1051,18 +1103,30 @@ reminder_get_days_string( struct event_stored *current )
       int month = current->days >> 16;
 
       if( day % 10 == 1 )
-	pos = sprintf( string, "%dst", day );
+	//pos = sprintf( string, "%dst", day );
+        string = g_strdup_printf("%dst", day );
       else if( day % 10 == 2 )
-	pos = sprintf( string, "%dnd", day );
+	//pos = sprintf( string, "%dnd", day );
+        string = g_strdup_printf("%dnd", day );
       else if( day % 10 == 3 )
-	pos = sprintf( string, "%drd", day );
+	//pos = sprintf( string, "%drd", day );
+        string = g_strdup_printf("%drd", day );
       else
-	pos = sprintf( string, "%dth", day );
+	//pos = sprintf( string, "%dth", day );
+        string = g_strdup_printf("%dth", day );
 
-      if( month == 1 )
-	sprintf( string + pos, " of every month" );
-      else
-	sprintf( string + pos, " of every %d months", month );
+      if( month == 1 ) {
+	//sprintf( string + pos, " of every month" );
+        string2 = g_strdup_printf(" of every month" );
+        g_strconcat(string, string2, NULL);
+        g_free(string2);
+      }
+      else {
+	//sprintf( string + pos, " of every %d months", month );
+          string2 = g_strdup_printf(" of every %d months", month );
+          g_strconcat(string, string2, NULL);
+          g_free(string2);
+      }
     }
 
   return string;
@@ -1073,16 +1137,16 @@ reminder_ui_to_event_stored( struct event_stored *current )
 {
   gchar *name;
 
-  name = gtk_entry_get_text( GTK_ENTRY( entry_event ) );
+  name = (gchar *) gtk_entry_get_text( GTK_ENTRY( entry_event ) );
   if( strlen( name ) < 1 )
     {
       gkrellm_message_window( str_title, "ERROR: You must enter a name for this event.", entry_event );
       return NULL;
     }
-  current->name = malloc( strlen( name ) );
-  if( !current->name )
-    return NULL;
-  strcpy( current->name, name );
+//  current->name = malloc( strlen( name ) );
+//  if( !current->name )
+//    return NULL;
+  current->name = g_strdup(name );
 
   tm_input.tm_mon = gtk_spin_button_get_value_as_int( GTK_SPIN_BUTTON( spin_start_month ) ) - 1;
   tm_input.tm_mday = gtk_spin_button_get_value_as_int( GTK_SPIN_BUTTON( spin_start_day ) );
@@ -1123,7 +1187,7 @@ reminder_ui_to_event_stored( struct event_stored *current )
     {
       gkrellm_message_window( str_title, "ERROR: End date can't be smaller than start date.", spin_start_day );
 
-      free( current->name );
+      g_free( current->name );
       return NULL;
     }
 
@@ -1148,7 +1212,7 @@ reminder_ui_to_event_stored( struct event_stored *current )
       if( !current->days )
 	{
 	  gkrellm_message_window( str_title, "ERROR: You must select at least one day.", check_sun );
-	  free( current->name );
+	  g_free( current->name );
 	  return NULL;
 	}
 
@@ -1208,7 +1272,7 @@ cb_add_entry( struct event_stored *event, gint row )
   gtk_clist_columns_autosize( GTK_CLIST( list_main ) );
 
   if( array[1] )
-    free( array[1] );
+    g_free( array[1] );
   if( array[2] )
     free( array[2] );
   if( array[3] )
@@ -1846,8 +1910,8 @@ create_calendar_time()
       gtk_spin_button_update( GTK_SPIN_BUTTON( spin_time_hour ) );
     }
 
-  gtk_signal_connect( GTK_OBJECT( button_ampm ), "clicked",
-		      (GtkSignalFunc) cb_ampm_clicked, NULL );
+  g_signal_connect( G_OBJECT( button_ampm ), "clicked",
+		      G_CALLBACK(cb_ampm_clicked), NULL );
 
   gtk_box_pack_start( GTK_BOX( hbox_time ), label_time, FALSE, FALSE, 2 );
   gtk_box_pack_start( GTK_BOX( hbox_time ), spin_time_hour, FALSE, FALSE, 2 );
@@ -1900,9 +1964,12 @@ create_calendar_date_date( gboolean isStart )
   gtk_spin_button_set_numeric( GTK_SPIN_BUTTON( *spin_day ), TRUE );
   gtk_spin_button_set_numeric( GTK_SPIN_BUTTON( *spin_year ), TRUE );
 
-  gtk_signal_connect( adj_month, "value-changed", GTK_SIGNAL_FUNC( cb_date_changed ), *spin_month );
-  gtk_signal_connect( adj_day, "value-changed", GTK_SIGNAL_FUNC( cb_date_changed ), *spin_day );
-  gtk_signal_connect( adj_year, "value-changed", GTK_SIGNAL_FUNC( cb_date_changed ), *spin_year );
+  g_signal_connect( adj_month, "value-changed",
+        G_CALLBACK( cb_date_changed ), *spin_month );
+  g_signal_connect( adj_day, "value-changed",
+        G_CALLBACK( cb_date_changed ), *spin_day );
+  g_signal_connect( adj_year, "value-changed",
+        G_CALLBACK( cb_date_changed ), *spin_year );
 
   gtk_box_pack_start( GTK_BOX( hbox_date_date ), label, FALSE, FALSE, 2 );
   gtk_box_pack_start( GTK_BOX( hbox_date_date ), *spin_month, FALSE, FALSE, 2 );
@@ -1926,7 +1993,8 @@ create_calendar_date()
   hbox_end = create_calendar_date_date( FALSE );
 
   check_forever = gtk_check_button_new_with_label( "Forever" );
-  gtk_signal_connect( GTK_OBJECT( check_forever ), "clicked", GTK_SIGNAL_FUNC( cb_forever ), NULL );
+  g_signal_connect( G_OBJECT( check_forever ), "clicked",
+         G_CALLBACK( cb_forever ), NULL );
 
   gtk_box_pack_start( GTK_BOX( hbox_date ), hbox_start, TRUE, TRUE, 2 );
   gtk_box_pack_start( GTK_BOX( hbox_date ), hbox_end, TRUE, TRUE, 2 );
@@ -1954,14 +2022,14 @@ create_calendar_ops()
   gtk_widget_set_sensitive( GTK_WIDGET( button_remove ), FALSE );
   gtk_widget_set_sensitive( GTK_WIDGET( button_update ), FALSE );
 
-  gtk_signal_connect( GTK_OBJECT( button_add ), "clicked",
-		      GTK_SIGNAL_FUNC( cb_add ), NULL );
-  gtk_signal_connect( GTK_OBJECT( button_remove ), "clicked",
-		      GTK_SIGNAL_FUNC( cb_remove ), NULL );
-  gtk_signal_connect( GTK_OBJECT( button_update ), "clicked",
-		      GTK_SIGNAL_FUNC( cb_update ), NULL );
-  gtk_signal_connect( GTK_OBJECT( button_reset ), "clicked",
-		      GTK_SIGNAL_FUNC( cb_reset ), NULL );
+  g_signal_connect( G_OBJECT( button_add ), "clicked",
+		      G_CALLBACK( cb_add ), NULL );
+  g_signal_connect( G_OBJECT( button_remove ), "clicked",
+		      G_CALLBACK( cb_remove ), NULL );
+  g_signal_connect( G_OBJECT( button_update ), "clicked",
+		      G_CALLBACK( cb_update ), NULL );
+  g_signal_connect( G_OBJECT( button_reset ), "clicked",
+		      G_CALLBACK( cb_reset ), NULL );
 
   gtk_box_pack_start( GTK_BOX( hbox_ops ), button_add, TRUE, TRUE, 10 );
   gtk_box_pack_start( GTK_BOX( hbox_ops ), button_remove, TRUE, TRUE, 10 );
@@ -1986,12 +2054,12 @@ create_calendar_list()
   list_main = gtk_clist_new_with_titles( 5, list_titles );
   list_main_row_selected = -1;
 
-  gtk_signal_connect( GTK_OBJECT( list_main ), "select_row",
-		      GTK_SIGNAL_FUNC( cb_row_select ), NULL );
-  gtk_signal_connect( GTK_OBJECT( list_main ), "unselect_row",
-		      GTK_SIGNAL_FUNC( cb_row_unselect ), NULL );
-  gtk_signal_connect( GTK_OBJECT( list_main ), "click_column",
-		      GTK_SIGNAL_FUNC( cb_column_click ), NULL );
+  g_signal_connect( G_OBJECT( list_main ), "select_row",
+		      G_CALLBACK( cb_row_select ), NULL );
+  g_signal_connect( G_OBJECT( list_main ), "unselect_row",
+		      G_CALLBACK( cb_row_unselect ), NULL );
+  g_signal_connect( G_OBJECT( list_main ), "click_column",
+		      G_CALLBACK( cb_column_click ), NULL );
 
   gtk_clist_set_selection_mode( GTK_CLIST( list_main ), GTK_SELECTION_SINGLE );
   gtk_clist_column_titles_active( GTK_CLIST( list_main ) );
@@ -2016,12 +2084,12 @@ create_calendar_occurs()
   radio_monthly = gtk_radio_button_new_with_label( gtk_radio_button_group( GTK_RADIO_BUTTON( radio_daily ) ),
 						   "Monthly" );
 
-  gtk_signal_connect( GTK_OBJECT( radio_daily ), "clicked",
-		      GTK_SIGNAL_FUNC( cb_select_radio ), NULL );
-  gtk_signal_connect( GTK_OBJECT( radio_weekly ), "clicked",
-		      GTK_SIGNAL_FUNC( cb_select_radio ), NULL );
-  gtk_signal_connect( GTK_OBJECT( radio_monthly ), "clicked",
-		      GTK_SIGNAL_FUNC( cb_select_radio ), NULL );
+  g_signal_connect( G_OBJECT( radio_daily ), "clicked",
+		      G_CALLBACK( cb_select_radio ), NULL );
+  g_signal_connect( G_OBJECT( radio_weekly ), "clicked",
+		      G_CALLBACK( cb_select_radio ), NULL );
+  g_signal_connect( G_OBJECT( radio_monthly ), "clicked",
+		      G_CALLBACK( cb_select_radio ), NULL );
 
   gtk_box_pack_start( GTK_BOX( vbox_occurs ), radio_daily, FALSE, FALSE, 2 );
   gtk_box_pack_start( GTK_BOX( vbox_occurs ), radio_weekly, FALSE, FALSE, 2 );
@@ -2112,12 +2180,12 @@ create_calendar_weekly()
   button_weekends = gtk_button_new_with_label( " Weekends " );
   button_clear = gtk_button_new_with_label( "   Clear   " );
 
-  gtk_signal_connect( GTK_OBJECT( button_weekdays ), "clicked",
-		      GTK_SIGNAL_FUNC( cb_set_days ), GINT_TO_POINTER( 1 ) );
-  gtk_signal_connect( GTK_OBJECT( button_weekends ), "clicked",
-		      GTK_SIGNAL_FUNC( cb_set_days ), GINT_TO_POINTER( 2 ) );
-  gtk_signal_connect( GTK_OBJECT( button_clear ), "clicked",
-		      GTK_SIGNAL_FUNC( cb_set_days ), GINT_TO_POINTER( 0 ) );
+  g_signal_connect( G_OBJECT( button_weekdays ), "clicked",
+		      G_CALLBACK( cb_set_days ), GINT_TO_POINTER( 1 ) );
+  g_signal_connect( G_OBJECT( button_weekends ), "clicked",
+		      G_CALLBACK( cb_set_days ), GINT_TO_POINTER( 2 ) );
+  g_signal_connect( G_OBJECT( button_clear ), "clicked",
+		      G_CALLBACK( cb_set_days ), GINT_TO_POINTER( 0 ) );
 
   gtk_box_pack_start( GTK_BOX( hbox_weekly_buttons ), button_weekdays, FALSE, FALSE, 2 );
   gtk_box_pack_start( GTK_BOX( hbox_weekly_buttons ), button_weekends, FALSE, FALSE, 2 );
@@ -2411,7 +2479,7 @@ create_help_frame( GtkWidget *tab )
   GtkWidget *text_main;
 
   static gchar *str_info[] = {
-    "<b>Calendar\n",
+    "<h>Calendar\n",
     "<i>Event: ", "Name of event. This will be displayed when you are reminded.\n\n",
     "<i>Daily: ", "This will remind you every <n> days starting with the start date. If the event\n",
     "does not occur on the end date, the actual ending date may be several days earlier\n",
@@ -2428,7 +2496,7 @@ create_help_frame( GtkWidget *tab )
     "<i>Remove: ", "Removes the currently selected event in the list.\n",
     "<i>Update: ", "Replaces the currently selected list item with the current event.\n",
     "<i>Today: ", "Resets the Start/End/Time to the current time and date.\n\n",
-    "<b>Settings\n",
+    "<h>Settings\n",
     "<i>Remind Early: ", "Reminders will appear <n> minutes before they are scheduled.\n",
     "<i>Remind Missed: ", "Reminders that happened before GKrellM was started will appear\n",
     "at startup.\n",
@@ -2437,11 +2505,11 @@ create_help_frame( GtkWidget *tab )
     "<i>Time Format: ", "Select either 12 hour (with AM/PM) or 24-hour time display\n",
     "<i>Date Format: ", "The format to use when displaying dates.\n",
     "<i>Notification Command: ", "This command will be executed whenever a new event occurs\n\n",
-    "<b>Reminders\n",
+    "<h>Reminders\n",
     "<i>Never: ", "Deletes the event from the calendar. It will never appear again.\n",
     "<i>Later: ", "Will display this reminder again in <n> minutes.\n",
     "<i>Dismiss: ", "Acknowledges the reminder. It will not be displayed again today.\n\n",
-    "<b>Panel\n",
+    "<h>Panel\n",
     "The first number indicates the number of events pending. The second number\n",
     "indicates the total number of events for today. The calendar will also flash when\n",
     "there are pending events.\n\n",
@@ -2452,8 +2520,9 @@ create_help_frame( GtkWidget *tab )
 
   vbox_main = gtk_vbox_new( TRUE, 2 );
 
-  text_main = gkrellm_scrolled_text( vbox_main, NULL, GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
-  gkrellm_add_info_text( text_main, str_info, 59 );
+  text_main = gkrellm_gtk_scrolled_text_view( vbox_main, NULL, GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
+//  gkrellm_add_info_text( text_main, str_info, 59 );
+  gkrellm_gtk_text_view_append_strings(text_main, str_info, 59);
 
   gtk_widget_show_all( vbox_main );
 
@@ -2542,7 +2611,7 @@ display_config( GtkWidget *tab )
 }
 
 static void
-update_config()
+update_config(void)
 {
   struct id_list *dl_current;
   struct event_stored *es_tail;
@@ -2583,19 +2652,20 @@ update_config()
 
   if( !strlen( gtk_entry_get_text( GTK_ENTRY( entry_notify ) ) ) )
     {
-      free( config.notify );
-      config.notify = NULL;
+      g_free( config.notify );
+      config.notify = g_strdup(str_null);
     }
   else if( !config.notify || strcmp( config.notify, gtk_entry_get_text( GTK_ENTRY( entry_notify ) ) ) )
     {
       if( config.notify )
-	free( config.notify );
+	g_free( config.notify );
 
-      config.notify = malloc( strlen( gtk_entry_get_text( GTK_ENTRY( entry_notify ) ) ) + 1 );
-      if( !config.notify )
-	return;
+//      config.notify = malloc( strlen( gtk_entry_get_text( GTK_ENTRY( entry_notify ) ) ) + 1 );
+//      if( !config.notify )
+//	return;
 
-      strcpy( config.notify, gtk_entry_get_text( GTK_ENTRY( entry_notify ) ) );
+//      strcpy( config.notify, gtk_entry_get_text( GTK_ENTRY( entry_notify ) ) );
+      config.notify = g_strdup(gtk_entry_get_text( GTK_ENTRY( entry_notify ) ) );
     }
 
   /* Make sure that the list is loaded (fixes apply/ok bug) */
@@ -2648,10 +2718,11 @@ default_config()
   config.ampm = TRUE;
   config.mdy = TRUE;
 
-  config.event_file = malloc( strlen( gkrellm_homedir() ) + 29 );
-  if( !config.event_file )
-    return;
-  sprintf( config.event_file, "%s/.gkrellm-reminder/event.dat", gkrellm_homedir() );
+//  config.event_file = malloc( strlen( gkrellm_homedir() ) + 29 );
+//  if( !config.event_file )
+//    return;
+  //sprintf( config.event_file, "%s/.gkrellm-reminder/event.dat", gkrellm_homedir() );
+  config.event_file = g_strdup_printf("%s/.gkrellm-reminder/event.dat", gkrellm_homedir() );
 }
 
 static void
@@ -2664,7 +2735,8 @@ save_config( FILE *fp )
   fprintf( fp, "%s ampm %d\n", CONFIG_NAME, config.ampm );
   fprintf( fp, "%s mdy %d\n", CONFIG_NAME, config.mdy );
   fprintf( fp, "%s alert %d\n", CONFIG_NAME, config.alert );
-  fprintf( fp, "%s notify %s\n", CONFIG_NAME, config.notify ? config.notify : str_null );
+  if (config.notify && strcmp(config.notify, str_null))
+    fprintf( fp, "%s notify %s\n", CONFIG_NAME, config.notify ? config.notify : str_null );
 }
 
 static void
@@ -2698,15 +2770,16 @@ load_config( gchar *arg )
   else if( !strcmp( keyword, "notify" ) )
     {
       if( config.notify )
-	free( config.notify );
+	   g_free( config.notify );
 
       if( strcmp( value, str_null ) )
       {
-	config.notify = malloc( strlen( value ) + 1 );
-	if( !config.notify )
-	  return;
+//	config.notify = malloc( strlen( value ) + 1 );
+//	if( !config.notify )
+//	  return;
 
-	strcpy( config.notify, value );
+//	strcpy( config.notify, value );
+          config.notify = g_strdup(value);
       }
     }
 }
@@ -2737,12 +2810,12 @@ reminder_display_today( void )
   if( window_today )
     return;
 
-  window_today = gtk_window_new( GTK_WINDOW_DIALOG );
+  window_today = gtk_window_new( GTK_WINDOW_TOPLEVEL );
   gtk_window_set_policy( GTK_WINDOW( window_today ), TRUE, TRUE, FALSE );
   gtk_window_set_title( GTK_WINDOW( window_today ), str_title );
   gtk_widget_set_usize( window_today, 200, 200 );
-  gtk_signal_connect( GTK_OBJECT( window_today ), "delete_event",
-		      (GtkSignalFunc) cb_today_delete, NULL );
+  g_signal_connect( G_OBJECT( window_today ), "delete_event",
+		      G_CALLBACK(cb_today_delete), NULL );
 
   vbox_main = gtk_vbox_new( FALSE, 5 );
   gtk_container_add( GTK_CONTAINER( window_today ), vbox_main );
@@ -2789,8 +2862,8 @@ reminder_display_today( void )
   separator = gtk_hseparator_new();
 
   button_close = gtk_button_new_with_label( "Close" );
-  gtk_signal_connect_object( GTK_OBJECT( button_close ), "clicked",
-			     (GtkSignalFunc) cb_today_delete, GTK_OBJECT( window_today ) );
+  g_signal_connect_swapped( G_OBJECT( button_close ), "clicked",
+			     G_CALLBACK(cb_today_delete), GTK_OBJECT( window_today ) );
 
   gtk_box_pack_start( GTK_BOX( vbox_main ), scroll_today, TRUE, TRUE, 2 );
   gtk_box_pack_start( GTK_BOX( vbox_main ), separator, FALSE, FALSE, 2 );
@@ -2865,14 +2938,16 @@ reminder_window_later( GtkWidget *window, gpointer data )
     {
       if( !strstr( event_active.name, str_delayed ) )
 	{
-	  new->name = malloc( strlen( event_active.name ) + 1 + 10 );
-	  strcpy( new->name, str_delayed );
-	  strcpy( new->name + 10, event_active.name );
+//	  new->name = malloc( strlen( event_active.name ) + 1 + 10 );
+//	  strcpy( new->name, str_delayed );
+//	  strcpy( new->name + 10, event_active.name );
+      new->name = g_strdup_printf("%10s%s", str_delayed, event_active.name);
 	}
       else
 	{
-	  new->name = malloc( strlen( event_active.name ) + 1 );
-	  strcpy( new->name, event_active.name );
+//	  new->name = malloc( strlen( event_active.name ) + 1 );
+//	  strcpy( new->name, event_active.name );
+      new->name = g_strdup(event_active.name);
 
 	  if( !head_stored )
 	    reminder_load_stored();
@@ -2962,11 +3037,12 @@ reminder_get_active()
     {
       memcpy( &event_active, head_today, sizeof( struct event_today ) );
 
-      event_active.name = malloc( strlen( head_today->name ) + 1 );
-      if( !event_active.name )
-	return 0;
+//      event_active.name = malloc( strlen( head_today->name ) + 1 );
+//      if( !event_active.name )
+//	return 0;
 
-      strcpy( event_active.name, head_today->name );
+//      strcpy( event_active.name, head_today->name );
+      event_active.name = g_strdup(head_today->name);
 
       if( !strstr( event_active.name, str_delayed ) )
 	event_active.occurs += config.remind_early * SECS_PER_MIN;
@@ -3020,11 +3096,11 @@ reminder_display_reminder( void )
   if( !id_active )
     return;
 
-  window_reminder = gtk_window_new( GTK_WINDOW_DIALOG );
+  window_reminder = gtk_window_new( GTK_WINDOW_TOPLEVEL );
   gtk_window_set_policy( GTK_WINDOW( window_reminder ), TRUE, TRUE, FALSE );
   gtk_window_set_title( GTK_WINDOW( window_reminder ), str_title );
-  gtk_signal_connect( GTK_OBJECT( window_reminder ), "delete-event",
-		      GTK_SIGNAL_FUNC( cb_reminder_delete ), NULL );
+  g_signal_connect( G_OBJECT( window_reminder ), "delete-event",
+		      G_CALLBACK( cb_reminder_delete ), NULL );
 
   vbox_main = gtk_vbox_new( FALSE, 5 );
   gtk_container_add( GTK_CONTAINER( window_reminder ), vbox_main );
@@ -3068,14 +3144,14 @@ reminder_display_reminder( void )
   button_later = gtk_button_new_with_label( " Later " );
   button_dismiss = gtk_button_new_with_label( " Dismiss " );
 
-  gtk_signal_connect( GTK_OBJECT( button_never ), "clicked",
-		      (GtkSignalFunc) reminder_window_never,
+  g_signal_connect( G_OBJECT( button_never ), "clicked",
+		      G_CALLBACK(reminder_window_never),
 		      GINT_TO_POINTER( head_today->id ) );
-  gtk_signal_connect( GTK_OBJECT( button_later ), "clicked",
-		      (GtkSignalFunc) reminder_window_later,
+  g_signal_connect( G_OBJECT( button_later ), "clicked",
+		      G_CALLBACK(reminder_window_later),
 		      GINT_TO_POINTER( head_today->id ) );
-  gtk_signal_connect( GTK_OBJECT( button_dismiss ), "clicked",
-		      (GtkSignalFunc) reminder_window_dismiss,
+  g_signal_connect( G_OBJECT( button_dismiss ), "clicked",
+		      G_CALLBACK(reminder_window_dismiss),
 		      GINT_TO_POINTER( head_today->id ) );
 
   gtk_box_pack_start( GTK_BOX( hbox_buttons ), button_never, FALSE, FALSE, 0 );
@@ -3090,8 +3166,8 @@ reminder_display_reminder( void )
 static void
 reminder_draw_panel_text( gint num_active, gint num_today )
 {
-  Style *style;
-  TextStyle ts, ts_old;
+  GkrellmStyle *style;
+  GkrellmTextstyle ts, ts_old;
   gint new_value;
   gint x, w;
   gchar buf[16];
@@ -3114,8 +3190,8 @@ reminder_draw_panel_text( gint num_active, gint num_today )
     }
 
   style = gkrellm_meter_style( style_id );
-  x = gkrellm_chart_width() * panel->label->position / LABEL_MAX;
-  x -= style->margin + w / 2;
+  x = gkrellm_chart_width() * panel->label->position / GKRELLM_LABEL_MAX;
+  x -= style->margin.left + w / 2;
 
   if ( panel->label->position >= 50 )
     x -= reminder_icon_decal->w / 2;
@@ -3131,18 +3207,18 @@ reminder_draw_panel_text( gint num_active, gint num_today )
 }
 
 static void
-update_plugin()
+update_plugin(void)
 {
   static gint frame = 0;
 
-  if( GK.day_tick )
+  if( pGK->day_tick )
     {
       if( !head_stored )
 	reminder_load_stored();
 
       reminder_build_today( FALSE );
     }
-  if( GK.minute_tick )
+  if( pGK->minute_tick )
     {
       time_t now;
 
@@ -3150,7 +3226,7 @@ update_plugin()
 
       reminder_check_new_active( head_today, last_active, now );
     }
-  if( ( GK.timer_ticks % 2 ) == 0 )
+  if( ( pGK->timer_ticks % 2 ) == 0 )
     {
       if( config.alert & ALERT_FLASH )
 	{
@@ -3164,7 +3240,7 @@ update_plugin()
 
       gkrellm_draw_decal_pixmap( panel, DECAL( panel ), frame );
       reminder_draw_panel_text( num_active, num_today );
-      gkrellm_draw_layers( panel );
+      gkrellm_draw_panel_layers( panel );
     }
 }
 
@@ -3192,7 +3268,7 @@ cb_panel_press( GtkWidget * widget, GdkEventButton * ev )
 }
 
 static void
-cb_reminder_button( DecalButton *button )
+cb_reminder_button( GkrellmDecalbutton *button )
 {
   if( num_active )
     reminder_display_reminder();
@@ -3201,8 +3277,12 @@ cb_reminder_button( DecalButton *button )
 static void
 create_plugin(GtkWidget *vbox, gint first_create)
 {
-  Style	*style;
+  GkrellmStyle	*style;
   gint  x, w;
+#if !defined(GKRELLM_HAVE_THEME_SCALE)
+  static GdkPixmap *reminder_icon_pixmap;
+  static GdkBitmap *reminder_icon_mask;
+#endif
 
   if (first_create)
     panel = gkrellm_panel_new0();
@@ -3212,22 +3292,25 @@ create_plugin(GtkWidget *vbox, gint first_create)
   style = gkrellm_meter_style(style_id);
 
   /* Load icon image */
-  gkrellm_load_image( NULL, calendar_xpm, &reminder_icon_image, STYLE_NAME );
-  gkrellm_render_to_pixmap( reminder_icon_image,
-			    &reminder_icon_pixmap,
-			    &reminder_icon_mask,
-			    0, 0 );
+  gkrellm_load_piximage( NULL, calendar_xpm, &reminder_icon_image, STYLE_NAME);
+
+#if defined(GKRELLM_HAVE_THEME_SCALE)
+  reminder_icon_decal = gkrellm_make_scaled_decal_pixmap(panel,
+							reminder_icon_image,
+							style, 2, -1, -1, 0, 0);
+#else
+  gkrellm_scale_piximage_to_pixmap(reminder_icon_image, &reminder_icon_pixmap,
+      &reminder_icon_mask, 0, 0);
   reminder_icon_decal = gkrellm_create_decal_pixmap( panel,
-						     reminder_icon_pixmap,
-						     reminder_icon_mask,
-						     2,
-						     style, -1, -1 );
+						     reminder_icon_pixmap, reminder_icon_mask,
+						     2, style, -1, -1 );
+#endif
 
   /* Setup text decal for numbers */
-  x = style->margin;
+  x = style->margin.left;
   if( style->label_position >= 50 )
     x += reminder_icon_decal->w;
-  w = gkrellm_chart_width() - reminder_icon_decal->w - 2 * style->margin;
+  w = gkrellm_chart_width() - reminder_icon_decal->w - 2 * style->margin.left;
 
   panel->textstyle = gkrellm_meter_textstyle(style_id);
 
@@ -3235,35 +3318,36 @@ create_plugin(GtkWidget *vbox, gint first_create)
 						   "0",
 						   panel->textstyle,
 						   style, x, -1, w );
-
-  gkrellm_configure_panel( panel, NULL, style );
-  gkrellm_create_panel( vbox, panel, gkrellm_bg_meter_image( style_id ) );
-
   if( reminder_icon_decal->h > reminder_text_decal->h )
-    reminder_text_decal->y += ( reminder_icon_decal->h - reminder_text_decal->h ) / 2;
+    reminder_text_decal->y += (reminder_icon_decal->h - reminder_text_decal->h ) / 2;
   else
     reminder_icon_decal->y += ( reminder_text_decal->h - reminder_icon_decal->h ) / 2;
 
-  reminder_text_button = gkrellm_put_decal_in_meter_button( panel, reminder_text_decal,
-							    cb_reminder_button, NULL );
+  reminder_text_button = gkrellm_put_decal_in_meter_button( panel,
+							reminder_text_decal,
+							cb_reminder_button, NULL, NULL );
+  gkrellm_panel_configure( panel, NULL, style );
+  gkrellm_panel_create( vbox, reminder_mon, panel);
+      //, gkrellm_bg_meter_image( style_id ) );
+
   reminder_text_button_enable();
 
-  gkrellm_monitor_height_adjust(panel->h);
+//  gkrellm_monitor_height_adjust(panel->h);
 
   if (first_create)
     {
-      gtk_signal_connect(GTK_OBJECT (panel->drawing_area), "expose_event",
-			 (GtkSignalFunc) panel_expose_event, NULL);
-      gtk_signal_connect( GTK_OBJECT( panel->drawing_area ),
+      g_signal_connect(G_OBJECT (panel->drawing_area), "expose_event",
+			 G_CALLBACK(panel_expose_event), NULL);
+      g_signal_connect( G_OBJECT( panel->drawing_area ),
 			  "button_press_event",
-			  ( GtkSignalFunc ) cb_panel_press, NULL );
+			  G_CALLBACK(cb_panel_press), NULL );
 
       reminder_load_stored();
       reminder_build_today( FALSE );
     }
 }
 
-static Monitor	reminder_monitor	=
+static GkrellmMonitor	reminder_monitor	=
 {
   "Reminder",   		/* Title for config clist.   */
   0,				/* Id,  0 if a plugin       */
@@ -3286,10 +3370,21 @@ static Monitor	reminder_monitor	=
   NULL				/* path if a plugin, filled in by GKrellM   */
 };
 
-Monitor *
-init_plugin()
+#if defined(WIN32)
+    __declspec(dllexport) GkrellmMonitor *
+    gkrellm_init_plugin(win32_plugin_callbacks* calls)
+#else
+    GkrellmMonitor *
+    gkrellm_init_plugin()
+#endif
 {
-  reminder_mon = &reminder_monitor;
+#if defined(WIN32)
+    callbacks = calls;
+#endif
+
+    pGK = gkrellm_ticks();
+
+    reminder_mon = &reminder_monitor;
 
   head_stored = NULL;
   head_today = NULL;
@@ -3297,6 +3392,8 @@ init_plugin()
   head_delete = NULL;
   last_active = NULL;
 
+  str_null = g_strdup("");
+
   num_active = 0;
   num_today = 0;
   today_day = 0;
